import { __awaiter, __decorate } from 'tslib';
import { ɵɵdefineInjectable, Injectable, EventEmitter, Input, Output, Component, NgModule } from '@angular/core';
import { animation, style, animate, trigger, transition } from '@angular/animations';
import { CommonModule } from '@angular/common';

var ACUANT_ALERT;
(function (ACUANT_ALERT) {
    ACUANT_ALERT["BIRTHDATE_VALID"] = "Birth Date Valid";
    ACUANT_ALERT["DOCUMENT_CLASSIFICATION"] = "Document Classification";
    ACUANT_ALERT["DOCUMENT_EXPIRED"] = "Document Expired";
    ACUANT_ALERT["EXPIRATION_DATE_VALID"] = "Expiration Date Valid";
    ACUANT_ALERT["IMAGE_TAMPERING_CHECK"] = "Image Tampering Check";
    ACUANT_ALERT["ISSUE_DATE_VALID"] = "Issue Date Valid";
    ACUANT_ALERT["PHYSICAL_DOCUMENT_PRESENCE"] = "Physical Document Presence";
    ACUANT_ALERT["BARCODE_READ"] = "2DBarcodeRead";
    ACUANT_ALERT["VISIBLE_PATTERN"] = "Visible Pattern";
    ACUANT_ALERT["VISIBLE_PATTERN_1"] = "Visible Pattern 1";
    ACUANT_ALERT["VISIBLE_PATTERN_2"] = "Visible Pattern 2";
    ACUANT_ALERT["VISIBLE_PATTERN_3"] = "Visible Pattern 3";
    ACUANT_ALERT["VISIBLE_PATTERN_4"] = "Visible Pattern 4";
    ACUANT_ALERT["VISIBLE_PATTERN_5"] = "Visible Pattern 5";
    ACUANT_ALERT["VISIBLE_PATTERN_6"] = "Visible Pattern 6";
})(ACUANT_ALERT || (ACUANT_ALERT = {}));

var ACUANT_FIELD;
(function (ACUANT_FIELD) {
    ACUANT_FIELD["ADDRESS"] = "Address";
    ACUANT_FIELD["ADDRESS_CITY"] = "Address City";
    ACUANT_FIELD["ADDRESS_LINE_1"] = "Address Line 1";
    ACUANT_FIELD["ADDRESS_LINE_2"] = "Address Line 2";
    ACUANT_FIELD["ADDRESS_POSTAL_CODE"] = "Address Postal Code";
    ACUANT_FIELD["BACK_NUMBER"] = "Back Number";
    ACUANT_FIELD["BACK_SECCION"] = "Back Seccion";
    ACUANT_FIELD["BIRTH_DATE"] = "Birth Date";
    ACUANT_FIELD["CURP"] = "CURP";
    ACUANT_FIELD["DOCUMENT_CLASS_NAME"] = "Document Class Name";
    ACUANT_FIELD["DOCUMENT_NUMBER"] = "Document Number";
    ACUANT_FIELD["EXPIRATION_DATE"] = "Expiration Date";
    ACUANT_FIELD["EXTRACTED_BIRTH_DATE_STRING"] = "Extracted Birth Date String";
    ACUANT_FIELD["FATHERS_SURNAME"] = "Father's Surname";
    ACUANT_FIELD["FINGERPRINT"] = "Fingerprint";
    ACUANT_FIELD["FIRST_NAME"] = "First Name";
    ACUANT_FIELD["FRONT_SECCION"] = "Front Seccion";
    ACUANT_FIELD["FULL_NAME"] = "Full Name";
    ACUANT_FIELD["GIVEN_NAME"] = "Given Name";
    ACUANT_FIELD["ISSUE_DATE"] = "Issue Date";
    ACUANT_FIELD["ISSUING_STATE_CODE"] = "Issuing State Code";
    ACUANT_FIELD["ISSUING_STATE_NAME"] = "Issuing State Name";
    ACUANT_FIELD["MIDDLE_NAME"] = "Middle Name";
    ACUANT_FIELD["MOTHERS_SURNAME"] = "Mother's Surname";
    ACUANT_FIELD["PERSONAL_NUMBER"] = "Personal Number";
    ACUANT_FIELD["PHOTO"] = "Photo";
    ACUANT_FIELD["REGISTRATION_DATE"] = "Registration Date";
    ACUANT_FIELD["REGISTRATION_YEAR"] = "Registration Year";
    ACUANT_FIELD["REGISTRATION_YEAR_AND_VERIFICATION_NUMBER"] = "Registration Year and Verification Number";
    ACUANT_FIELD["SEX"] = "Sex";
    ACUANT_FIELD["SIGNATURE"] = "Signature";
    ACUANT_FIELD["SURNAME"] = "Surname";
    ACUANT_FIELD["VERIFICATION_NUMBER"] = "Verification Number";
})(ACUANT_FIELD || (ACUANT_FIELD = {}));

// transitions
const FADE_IN_OUT_TRANSITION = animation([
    style({ opacity: '{{ start }}' }),
    animate('{{ time }}', style({ opacity: '{{ end }}' }))
], { params: { time: '1000ms', start: 0, end: 1 } });
const LEFT_TO_RIGHT_TRANSITION = animation([
    style({ transform: 'translateX(-100%)', opacity: '0' }),
    animate('{{ time }}', style({ transform: 'translateX(0)', opacity: '1' }))
], { params: { time: '400ms' } });
const UP_TO_DOWN_TRANSITION = animation([
    style({ height: '0', opacity: '0' }),
    animate('{{ time }}', style({ height: '*', opacity: '1' }))
], { params: { time: '1500ms' } });
const LEFT_TO_RIGHT_APPEAR_TRANSITION = animation([
    style({ width: '0%', opacity: '1' }),
    animate('{{ time }}', style({ width: '100%', opacity: '1' }))
], { params: { time: '15000ms' } });
// animations
const FADE_IN_OUT_ANIMATION = trigger('fadeInOut', [
    transition(':enter', [FADE_IN_OUT_TRANSITION])
]);
const LEFT_TO_RIGHT_ANIMATION = trigger('leftToRight', [
    transition(':enter', [LEFT_TO_RIGHT_TRANSITION])
]);
const UP_TO_DOWN_ANIMATION = trigger('upToDown', [
    transition(':enter', [UP_TO_DOWN_TRANSITION])
]);
const LEFT_TO_RIGHT_APPEAR_ANIMATION = trigger('leftToRightAppear', [
    transition(':enter', [LEFT_TO_RIGHT_APPEAR_TRANSITION])
]);

const CONFIGURATION_DEFAULT = {
    customization: {
        fadCustomization: {
            colors: {
                primary: '#A70635',
                secondary: '#A70635',
                tertiary: '#363636',
            },
            buttons: {
                primary: {
                    backgroundColor: '#A70635',
                    backgroundColorDisabled: '#dcdcdc',
                    labelColor: '#ffffff',
                    labelColorDisabled: '#8e8e8e',
                    border: '1px solid #A70635',
                },
                secondary: {
                    backgroundColor: '#363636ad',
                    backgroundColorDisabled: '#dcdcdc',
                    labelColor: '#ffffff',
                    labelColorDisabled: '#8e8e8e',
                    border: '1px solid #ffffff',
                },
                common: {
                    height: '50px',
                    width: '95%',
                    borderRadius: '10px',
                    padding: '1px 5px',
                    margin: '0px',
                    outline: 'none',
                },
            },
            fonts: {
                title: {
                    fontSize: '25px',
                    fontFamily: 'system-ui',
                },
                subtitle: {
                    fontSize: '17px',
                    fontFamily: 'system-ui',
                },
                content: {
                    fontSize: '15px',
                    fontFamily: 'system-ui',
                },
                informative: {
                    fontSize: '12px',
                    fontFamily: 'system-ui',
                },
                button: {
                    fontSize: '17px',
                    fontFamily: 'system-ui',
                },
            },
        },
        moduleCustomization: {
            legends: {
                initializing: 'iniciando',
                processing: 'procesando',
                scan: {
                    none: 'ENFOCA TU ID SOBRE LA GUÍA',
                    smallDocument: 'ACERCATE MÁS',
                    goodDocument: null,
                    capturing: 'CAPTURANDO',
                    tapToCapture: 'TOCA LA PANTALLA PARA CAPTURAR'
                },
                manualCapture: {
                    instruction: 'Captura el frente de tu identificación',
                    buttonNext: 'Continuar'
                }
            },
        },
    },
    instance: {
        AuthentsicationSensitivity: 0,
        ClassificationMode: 0,
        Device: {
            HasContactlessChipReader: false,
            HasMagneticStripeReader: false,
            SerialNumber: 'JavaScriptWebSDK 11.5.1',
            Type: {
                Manufacturer: 'xxx',
                Model: 'xxx',
                SensorType: 3,
            },
        },
        ImageCroppingExpectedSize: 0,
        ImageCroppingMode: 0,
        ManualDocumentType: null,
        ProcessMode: 0,
        SubscriptionId: '',
    },
    pathDependencies: {
        acuantDirectory: './assets/third-party/acuant/',
        imageDirectory: './assets/images/fad-acuant/'
    },
};

const ENDPOINTS = {
    DOCUMENT: '/AssureIDService/Document/',
    NEW_INSTANCE: 'Instance',
    UPLOAD_IMAGE_SIDE: '/Image?side=',
    UPLOAD_IMAGE_METRICS: '&light=0&metrics=true',
};

const getErrorDescription = (code) => {
    switch (code) {
        case -1:
            return 'Las credenciales son requeridas';
        case -2:
            return 'Error al inicializar acuant, una de las posibles causas son las credenciales incorrectas';
        case -3:
            return 'Cámara no soportada';
        case -4:
            return 'Error al inicializar la UI de acuant';
        case -5:
            return 'Error al crear una instancia del documento para otener el OCR, una de las posibles causas son las credenciales incorrectas';
        case -6:
            return 'Error al subir la imagen para obtener el OCR';
        case -7:
            return 'Error al obtener el OCR';
        case -8:
            return 'Error al obtener la imagen del rostro de la identificación';
        case -9:
            return 'No se encontró la url para obtener la imagen del rostro de la identificación';
        case -10:
            return 'No se encontró la imagen del rostro en la idetificación';
        case -11:
            return 'Error al obtener los recursos necesarios para inicializar el SDK';
        case -12:
            return 'Error inesperado en acuant, el detalle se muestra en la consola';
        default:
            return 'unknown error';
    }
};

var ErrorCode;
(function (ErrorCode) {
    ErrorCode[ErrorCode["REQUIRED_CREDENTIALS"] = -1] = "REQUIRED_CREDENTIALS";
    ErrorCode[ErrorCode["FAIL_INITIALIZATION"] = -2] = "FAIL_INITIALIZATION";
    ErrorCode[ErrorCode["UNSUPPORTED_CAMERA"] = -3] = "UNSUPPORTED_CAMERA";
    ErrorCode[ErrorCode["FAIL_INITIALIZATION_CAMERA_UI"] = -4] = "FAIL_INITIALIZATION_CAMERA_UI";
    ErrorCode[ErrorCode["FAIL_CREATION_INSTANCE_DOCUMENT"] = -5] = "FAIL_CREATION_INSTANCE_DOCUMENT";
    ErrorCode[ErrorCode["FAIL_UPLOAD_IMAGE"] = -6] = "FAIL_UPLOAD_IMAGE";
    ErrorCode[ErrorCode["FAIL_GET_OCR"] = -7] = "FAIL_GET_OCR";
    ErrorCode[ErrorCode["FAIL_GET_FACE_IMAGE"] = -8] = "FAIL_GET_FACE_IMAGE";
    ErrorCode[ErrorCode["FACE_IMAGE_URL_NOT_FOUND"] = -9] = "FACE_IMAGE_URL_NOT_FOUND";
    ErrorCode[ErrorCode["FACE_IMAGE_NOT_FOUND"] = -10] = "FACE_IMAGE_NOT_FOUND";
    ErrorCode[ErrorCode["RESOURCES_COULD_NOT_BE_LOADED"] = -11] = "RESOURCES_COULD_NOT_BE_LOADED";
    ErrorCode[ErrorCode["UNEXPECTED_ACUANT_ERROR"] = -12] = "UNEXPECTED_ACUANT_ERROR";
})(ErrorCode || (ErrorCode = {}));

let AcuantService = class AcuantService {
    constructor() { }
    createInstance(url, data, token) {
        const URL = `${url}${ENDPOINTS.DOCUMENT}${ENDPOINTS.NEW_INSTANCE}`;
        return fetch(URL, {
            method: 'POST',
            headers: {
                Authorization: `Basic ${token}`,
                Accept: 'application/json',
                'Content-Type': 'application/json',
            },
            body: JSON.stringify(data),
        }).then((response) => response.json());
    }
    uploadImage(url, instance, token, data, side) {
        const URL = `${url}${ENDPOINTS.DOCUMENT}${instance}${ENDPOINTS.UPLOAD_IMAGE_SIDE}${side}${ENDPOINTS.UPLOAD_IMAGE_METRICS}`;
        return fetch(URL, {
            method: 'POST',
            headers: {
                Authorization: `Basic ${token}`,
                'Content-Type': data.type
            },
            body: data,
        }).then((response) => {
            if (!response.ok)
                throw Error(`${response.status}: ${response.statusText}`);
        });
    }
    getOcr(url, instance, token) {
        const URL = `${url}${ENDPOINTS.DOCUMENT}${instance}`;
        return fetch(URL, {
            method: 'GET',
            headers: {
                Authorization: `Basic ${token}`,
                Accept: 'application/json',
            },
        }).then((response) => response.json());
    }
    getFaceImage(url, token) {
        return __awaiter(this, void 0, void 0, function* () {
            const response = yield fetch(url, {
                method: 'GET',
                headers: {
                    Authorization: `Basic ${token}`
                },
            });
            const blob = yield response.blob();
            return new Promise((resolve, reject) => {
                const reader = new FileReader();
                reader.onloadend = () => resolve(reader.result);
                reader.onerror = () => reject(this);
                reader.readAsDataURL(blob);
            });
        });
    }
};
AcuantService.ɵprov = ɵɵdefineInjectable({ factory: function AcuantService_Factory() { return new AcuantService(); }, token: AcuantService, providedIn: "root" });
AcuantService = __decorate([
    Injectable({
        providedIn: 'root',
    })
], AcuantService);

class AcuantResultIdData {
}

// implements fad customization common
class DefaultCustomization {
    constructor() {
        // fad
        this.fadCustomization = {};
        this.fadCustomization.colors = {};
        this.fadCustomization.buttons = {};
        this.fadCustomization.buttons.primary = {};
        this.fadCustomization.buttons.secondary = {};
        this.fadCustomization.buttons.common = {};
        this.fadCustomization.fonts = {};
        this.fadCustomization.fonts.title = {};
        this.fadCustomization.fonts.subtitle = {};
        this.fadCustomization.fonts.button = {};
        this.fadCustomization.fonts.informative = {};
        this.fadCustomization.fonts.content = {};
        // module
        this.moduleCustomization = {};
        this.moduleCustomization.legends = {};
    }
}

class ResponseError {
    constructor(code) {
        this.error = getErrorDescription(code);
        this.code = code;
    }
}

class Utils {
    static cameraOff(stream) {
        if (stream)
            stream.getTracks().forEach(track => track.stop());
    }
    static setCustomizationStyle(customization) {
        const setVariableCss = (name, value) => {
            document.documentElement.style.setProperty(name, value);
        };
        // fad commons
        // primary color
        setVariableCss('--fad-common-primary-color', customization.fadCustomization.colors.primary);
        setVariableCss('--fad-common-secondary-color', customization.fadCustomization.colors.secondary);
        setVariableCss('--fad-common-tertiary-color', customization.fadCustomization.colors.tertiary);
        // button
        // button primary
        setVariableCss('--fad-common-primary-button-background-color', customization.fadCustomization.buttons.primary.backgroundColor);
        setVariableCss('--fad-common-primary-button-background-color-disabled', customization.fadCustomization.buttons.primary.backgroundColorDisabled);
        setVariableCss('--fad-common-primary-button-label-color', customization.fadCustomization.buttons.primary.labelColor);
        setVariableCss('--fad-common-primary-button-label-color-disabled', customization.fadCustomization.buttons.primary.labelColorDisabled);
        setVariableCss('--fad-common-primary-button-border', customization.fadCustomization.buttons.primary.border);
        // button secondary
        setVariableCss('--fad-common-secondary-button-background-color', customization.fadCustomization.buttons.secondary.backgroundColor);
        setVariableCss('--fad-common-secondary-button-background-color-disabled', customization.fadCustomization.buttons.secondary.backgroundColorDisabled);
        setVariableCss('--fad-common-secondary-button-label-color', customization.fadCustomization.buttons.secondary.labelColor);
        setVariableCss('--fad-common-secondary-button-label-color-disabled', customization.fadCustomization.buttons.secondary.labelColorDisabled);
        setVariableCss('--fad-common-secondary-button-border', customization.fadCustomization.buttons.secondary.border);
        // button common
        setVariableCss('--fad-common-button-common-width', customization.fadCustomization.buttons.common.width);
        setVariableCss('--fad-common-button-common-height', customization.fadCustomization.buttons.common.height);
        setVariableCss('--fad-common-button-common-border-radius', customization.fadCustomization.buttons.common.borderRadius);
        setVariableCss('--fad-common-button-common-padding', customization.fadCustomization.buttons.common.padding);
        setVariableCss('--fad-common-button-common-margin', customization.fadCustomization.buttons.common.margin);
        setVariableCss('--fad-common-button-common-outline', customization.fadCustomization.buttons.common.outline);
        // fonts
        setVariableCss('--fad-common-title-font-size', customization.fadCustomization.fonts.title.fontSize);
        setVariableCss('--fad-common-title-font-family', customization.fadCustomization.fonts.title.fontFamily);
        setVariableCss('--fad-common-subtitle-font-size', customization.fadCustomization.fonts.subtitle.fontSize);
        setVariableCss('--fad-common-subtitle-font-family', customization.fadCustomization.fonts.subtitle.fontFamily);
        setVariableCss('--fad-common-content-font-size', customization.fadCustomization.fonts.content.fontSize);
        setVariableCss('--fad-common-content-font-family', customization.fadCustomization.fonts.content.fontFamily);
        setVariableCss('--fad-common-informative-font-size', customization.fadCustomization.fonts.informative.fontSize);
        setVariableCss('--fad-common-informative-font-family', customization.fadCustomization.fonts.informative.fontFamily);
        setVariableCss('--fad-common-button-font-size', customization.fadCustomization.fonts.button.fontSize);
        setVariableCss('--fad-common-button-font-family', customization.fadCustomization.fonts.button.fontFamily);
    }
    static removeCustomizationStyle() {
        window.document.documentElement.setAttribute('style', '');
    }
    static isIOS() {
        return (navigator.userAgent.indexOf('iPhone') > 0 ||
            navigator.userAgent.indexOf('iPad') > 0 ||
            (navigator.userAgent.indexOf('Macintosh') > -1 && 'ontouchend' in document));
    }
    static loadScript(path, id) {
        // separate in two parts because angular not support arrow function in static method
        const promise = new Promise((resolve, reject) => {
            const script = document.createElement('script');
            script.type = 'text/javascript';
            script.src = path;
            script.async = false;
            script.defer = true;
            script.id = id;
            script.onload = () => resolve();
            script.onerror = (error) => reject(error);
            document.getElementsByTagName('head')[0].appendChild(script);
        });
        return promise;
    }
    static createScript(content, id) {
        // separate in two parts because angular not support arrow function in static method
        const promise = new Promise((resolve, reject) => {
            const script = document.createElement('script');
            script.type = 'text/javascript';
            script.text = content;
            script.async = false;
            script.id = id;
            script.onload = () => resolve();
            script.onerror = (error) => reject(error);
            document.getElementsByTagName('head')[0].appendChild(script);
        });
        return promise;
    }
    static removeScripts(scripts) {
        scripts.forEach(element => {
            const script = document.getElementById(element);
            document.getElementById(element).parentNode.removeChild(script);
        });
    }
    static convertBase64ToBinary(imageBase64) {
        const base64 = imageBase64.replace(/^data[^,]+,/, '');
        return Uint8Array.from(atob(base64), c => c.charCodeAt(0));
    }
    static parseIdData(acuantDocument) {
        const ocr = {};
        const validation = {};
        const acuantField = {
            [ACUANT_FIELD.ADDRESS]: (value) => ocr.address = value,
            [ACUANT_FIELD.ADDRESS_CITY]: (value) => ocr.addressCity = value,
            [ACUANT_FIELD.ADDRESS_LINE_1]: (value) => ocr.addressLine1 = value,
            [ACUANT_FIELD.ADDRESS_LINE_2]: (value) => ocr.addressLine2 = value,
            [ACUANT_FIELD.ADDRESS_POSTAL_CODE]: (value) => ocr.addressPostalCode = value,
            [ACUANT_FIELD.BACK_NUMBER]: (value) => ocr.backNumber = value,
            [ACUANT_FIELD.BACK_SECCION]: (value) => ocr.backSeccion = value,
            [ACUANT_FIELD.BIRTH_DATE]: (value) => ocr.birthDate = value,
            [ACUANT_FIELD.CURP]: (value) => ocr.curp = value,
            [ACUANT_FIELD.DOCUMENT_CLASS_NAME]: (value) => ocr.documentClassName = value,
            [ACUANT_FIELD.DOCUMENT_NUMBER]: (value) => ocr.documentNumber = value,
            [ACUANT_FIELD.EXPIRATION_DATE]: (value) => ocr.expirationDate = value,
            [ACUANT_FIELD.EXTRACTED_BIRTH_DATE_STRING]: (value) => ocr.extractedBirthDate = value,
            [ACUANT_FIELD.FATHERS_SURNAME]: (value) => ocr.fathersSurname = value,
            [ACUANT_FIELD.FINGERPRINT]: (value) => ocr.fingerprint = value,
            [ACUANT_FIELD.FIRST_NAME]: (value) => ocr.firstName = value,
            [ACUANT_FIELD.FRONT_SECCION]: (value) => ocr.frontSeccion = value,
            [ACUANT_FIELD.FULL_NAME]: (value) => ocr.fullName = value,
            [ACUANT_FIELD.GIVEN_NAME]: (value) => ocr.givenName = value,
            [ACUANT_FIELD.ISSUE_DATE]: (value) => ocr.issueDate = value,
            [ACUANT_FIELD.ISSUING_STATE_CODE]: (value) => ocr.issuingStateCode = value,
            [ACUANT_FIELD.ISSUING_STATE_NAME]: (value) => ocr.issuingStateCode = value,
            [ACUANT_FIELD.MIDDLE_NAME]: (value) => ocr.middleName = value,
            [ACUANT_FIELD.MOTHERS_SURNAME]: (value) => ocr.mothersSurname = value,
            [ACUANT_FIELD.PERSONAL_NUMBER]: (value) => ocr.personalNumber = value,
            [ACUANT_FIELD.PHOTO]: (value) => ocr.photo = value,
            [ACUANT_FIELD.REGISTRATION_DATE]: (value) => ocr.registrationDate = value,
            [ACUANT_FIELD.REGISTRATION_YEAR]: (value) => ocr.registrationYear = value,
            [ACUANT_FIELD.REGISTRATION_YEAR_AND_VERIFICATION_NUMBER]: (value) => ocr.registrationYearAndVerificationNumber = value,
            [ACUANT_FIELD.SEX]: (value) => ocr.sex = value,
            [ACUANT_FIELD.VERIFICATION_NUMBER]: (value) => ocr.verificationNumber = value,
            [ACUANT_FIELD.SURNAME]: (value) => ocr.surname = value
        };
        const acuantAlert = {
            [ACUANT_ALERT.BARCODE_READ]: (value) => validation.barcodeRead = value,
            [ACUANT_ALERT.BIRTHDATE_VALID]: (value) => validation.birthDateValid = value,
            [ACUANT_ALERT.DOCUMENT_CLASSIFICATION]: (value) => validation.documentClassification = value,
            [ACUANT_ALERT.DOCUMENT_EXPIRED]: (value) => validation.documentExpired = value,
            [ACUANT_ALERT.EXPIRATION_DATE_VALID]: (value) => validation.expirationDateValid = value,
            [ACUANT_ALERT.IMAGE_TAMPERING_CHECK]: (value) => validation.imageTamperingCheck = value,
            [ACUANT_ALERT.ISSUE_DATE_VALID]: (value) => validation.issueDateValid = value,
            [ACUANT_ALERT.PHYSICAL_DOCUMENT_PRESENCE]: (value) => validation.physicalDocumentPresence = value,
            [ACUANT_ALERT.VISIBLE_PATTERN_1]: (value) => validation.visiblePattern1 = value,
            [ACUANT_ALERT.VISIBLE_PATTERN_2]: (value) => validation.visiblePattern2 = value,
            [ACUANT_ALERT.VISIBLE_PATTERN_3]: (value) => validation.visiblePattern3 = value,
            [ACUANT_ALERT.VISIBLE_PATTERN_4]: (value) => validation.visiblePattern4 = value,
            [ACUANT_ALERT.VISIBLE_PATTERN_5]: (value) => validation.visiblePattern5 = value,
            [ACUANT_ALERT.VISIBLE_PATTERN_6]: (value) => validation.visiblePattern6 = value,
        };
        if (acuantDocument && acuantDocument.Fields) {
            for (const field of acuantDocument.Fields) {
                if (acuantField[field.Key]) {
                    acuantField[field.Key](field.Value);
                }
            }
        }
        if (acuantDocument && acuantDocument.Alerts) {
            let countVisiblePattern = 1;
            acuantDocument.Alerts.map((alert, index) => {
                if (alert.Key === ACUANT_ALERT.VISIBLE_PATTERN) {
                    alert.Key = `${alert.Key} ${countVisiblePattern}`;
                    countVisiblePattern++;
                }
            });
            for (const alert of acuantDocument.Alerts) {
                if (acuantAlert[alert.Key]) {
                    acuantAlert[alert.Key](`${alert.Name}; ${alert.Information}; ${alert.Actions}; ${alert.Disposition}; ${alert.Result}`);
                }
            }
        }
        return { ocr, validation };
    }
    static mergeConfiguration(target, ...sources) {
        const isObject = (item) => {
            return (item && typeof item === 'object' && !Array.isArray(item));
        };
        if (!sources.length)
            return target;
        const source = sources.shift();
        if (isObject(target) && isObject(source)) {
            for (const key in source) {
                if (isObject(source[key])) {
                    if (!target[key])
                        Object.assign(target, { [key]: {} });
                    this.mergeConfiguration(target[key], source[key]);
                }
                else {
                    Object.assign(target, { [key]: source[key] });
                }
            }
        }
        return this.mergeConfiguration(target, ...sources);
    }
}

const DEPENDENCIES_FILES = {
    acuantSDK: { path: 'AcuantJavascriptWebSdk.min.js', id: 'scriptAcuantSDK' },
    acuantCamera: { path: 'AcuantCamera.min.js', id: 'scriptAcuantCamera' },
};
const DEPENDENCIES_TO_REMOVE = ['scriptAcuantSDK', 'scriptAcuantCamera', 'acuantConfig'];
let NgFadAcuantComponent = class NgFadAcuantComponent {
    constructor(service) {
        this.service = service;
        this.configuration = {};
        this.idData = false;
        this.idPhoto = false;
        this.imageQuality = 1;
        this.oncomplete = new EventEmitter();
        this.onerror = new EventEmitter();
        this.showAutomaticCapture = false;
        this.showManualCapture = false;
        this.activeBlackScreen = true;
        window['onAcuantSdkLoaded'] = () => {
            console.log('entry AcuantSdkLoaded');
            this.listenUnexpectedError();
            setTimeout(() => this.activeBlackScreen = false, 2000);
        };
    }
    ngOnInit() {
        if (this.credentials && this.credentials.passivePassword && this.credentials.passiveUsername && this.credentials.acasEndpoint && this.credentials.passiveSubscriptionId) {
            this.setCustomizationStyle();
            this.setDynamicConfiguration();
            Promise.all([this.loadAcuantSDK(), this.loadAcuantCamera()]).then(() => this.initializeAcuant()).catch();
        }
        else {
            this.onerror.emit(new ResponseError(ErrorCode.REQUIRED_CREDENTIALS));
        }
    }
    setCustomizationStyle() {
        this.configuration = Utils.mergeConfiguration(CONFIGURATION_DEFAULT, this.configuration);
        Utils.setCustomizationStyle(this.configuration.customization);
    }
    setDynamicConfiguration() {
        const script = `var acuantConfig = { path: '${this.configuration.pathDependencies.acuantDirectory}', jpegQuality: ${this.imageQuality} }`;
        Utils.createScript(script, 'acuantConfig');
    }
    loadAcuantSDK() {
        return new Promise((resolve) => {
            return Utils.loadScript(`${this.configuration.pathDependencies.acuantDirectory}${DEPENDENCIES_FILES.acuantSDK.path}`, DEPENDENCIES_FILES.acuantSDK.id).then(() => {
                window['loadAcuantSdk']();
                console.log('execute loadAcuantSdk');
                resolve();
            }).catch(error => {
                console.log(error);
                this.onerror.emit(new ResponseError(ErrorCode.RESOURCES_COULD_NOT_BE_LOADED));
            });
        });
    }
    listenUnexpectedError() {
        if (AcuantJavascriptWebSdk) {
            AcuantJavascriptWebSdk.setUnexpectedErrorCallback((error) => {
                console.log(JSON.stringify(error));
                this.onerror.emit(new ResponseError(ErrorCode.UNEXPECTED_ACUANT_ERROR));
            });
        }
    }
    loadAcuantCamera() {
        return new Promise((resolve) => {
            return Utils.loadScript(`${this.configuration.pathDependencies.acuantDirectory}${DEPENDENCIES_FILES.acuantCamera.path}`, DEPENDENCIES_FILES.acuantCamera.id).then(() => {
                resolve();
            }).catch(error => {
                console.log(error);
                this.onerror.emit(new ResponseError(ErrorCode.RESOURCES_COULD_NOT_BE_LOADED));
            });
        });
    }
    initializeAcuant() {
        this.showAutomaticCapture = true;
        const base64Token = btoa(this.credentials.passiveUsername + ':' + this.credentials.passivePassword);
        AcuantJavascriptWebSdk.initialize(base64Token, this.credentials.acasEndpoint, {
            onSuccess: () => {
                if (!this.isOldiOS())
                    AcuantJavascriptWebSdk.startWorkers(this.initDone.bind(this));
                else
                    AcuantJavascriptWebSdk.startWorkers(this.initDone.bind(this), [AcuantJavascriptWebSdk.ACUANT_IMAGE_WORKER]);
            },
            onFail: () => {
                this.onerror.emit(new ResponseError(ErrorCode.FAIL_INITIALIZATION));
            }
        });
    }
    initDone() {
        console.log('init done');
        this.activeBlackScreen = false;
        this.startCamera();
    }
    // code of AcuantSDK
    isOldiOS() {
        let ua = navigator.userAgent;
        let keyPhrase = "iPhone OS";
        const keyPhrase2 = "iPad; CPU OS";
        let index = ua.indexOf(keyPhrase);
        if (index < 0) {
            keyPhrase = keyPhrase2;
            index = ua.indexOf(keyPhrase);
        }
        if (index >= 0) {
            let version = ua.substring(index + keyPhrase.length + 1, index + keyPhrase.length + 3);
            try {
                let versionNum = parseInt(version);
                if (versionNum && versionNum < 13) {
                    return true;
                }
                else {
                    return false;
                }
            }
            catch (_) {
                return false;
            }
        }
        else {
            return false;
        }
    }
    startCamera() {
        const cameraCallback = {
            onCaptured: (response) => {
                this.activeBlackScreen = true;
                this.configuration.customization.moduleCustomization.legends.initializing = this.configuration.customization.moduleCustomization.legends.processing;
            },
            onFrameAvailable: (response) => {
            },
            onCropped: (response) => {
                if (response) {
                    this.imageResult = response;
                    AcuantCameraUI.end();
                    AcuantJavascriptWebSdk.endWorkers();
                    this.showAutomaticCapture = false;
                    if (this.documentInstance)
                        this.uploadImage(this.documentInstance, this.imageResult.image.data);
                    else
                        this.createInstance();
                }
                else {
                    this.startCamera();
                }
            }
        };
        if (AcuantCamera.isCameraSupported) {
            AcuantCameraUI.start(cameraCallback, (error, code) => {
                console.log(`error: ${error}. code ${code}`);
                this.showAutomaticCapture = false;
                this.startManualCapture();
            }, { text: this.getLegends() });
        }
        else
            this.onerror.emit(new ResponseError(ErrorCode.UNSUPPORTED_CAMERA));
    }
    startManualCapture() {
        this.showManualCapture = true;
        const cameraCallback = {
            onCaptured: (response) => {
                this.activeBlackScreen = true;
                this.configuration.customization.moduleCustomization.legends.initializing = this.configuration.customization.moduleCustomization.legends.processing;
            },
            onCropped: (response) => {
                if (response) {
                    this.imageResult = response;
                    AcuantCameraUI.end();
                    AcuantJavascriptWebSdk.endWorkers();
                    this.showManualCapture = false;
                    if (this.documentInstance)
                        this.uploadImage(this.documentInstance, this.imageResult.image.data);
                    else
                        this.createInstance();
                }
                else {
                    this.startCamera();
                }
            }
        };
        if (AcuantCamera.isCameraSupported) {
            AcuantCamera.startManualCapture(cameraCallback, (error) => {
                console.log(error);
                this.onerror.emit(new ResponseError(ErrorCode.FAIL_INITIALIZATION_CAMERA_UI));
            });
        }
        else
            this.onerror.emit(new ResponseError(ErrorCode.UNSUPPORTED_CAMERA));
    }
    getLegends() {
        return {
            NONE: this.configuration.customization.moduleCustomization.legends.scan.none,
            SMALL_DOCUMENT: this.configuration.customization.moduleCustomization.legends.scan.smallDocument,
            GOOD_DOCUMENT: this.configuration.customization.moduleCustomization.legends.scan.goodDocument,
            CAPTURING: this.configuration.customization.moduleCustomization.legends.scan.capturing,
            TAP_TO_CAPTURE: this.configuration.customization.moduleCustomization.legends.scan.tapToCapture,
        };
    }
    createInstance() {
        this.configuration.instance.SubscriptionId = this.credentials.passiveSubscriptionId;
        const token = btoa(`${this.credentials.passiveUsername}:${this.credentials.passivePassword}`);
        this.service.createInstance(this.credentials.assureidEndpoint, this.configuration.instance, token).then((doucmentInstance) => {
            this.uploadImage(doucmentInstance, this.imageResult.image.data);
        }).catch(error => this.onerror.emit(new ResponseError(ErrorCode.FAIL_CREATION_INSTANCE_DOCUMENT)));
    }
    uploadImage(documentInstance, image) {
        const token = btoa(`${this.credentials.passiveUsername}:${this.credentials.passivePassword}`);
        fetch(image).then(response => response.blob()).then(blob => {
            setTimeout(() => {
                this.service.uploadImage(this.credentials.assureidEndpoint, documentInstance, token, blob, this.side).then(() => {
                    if (this.idData)
                        this.getOcr(documentInstance);
                    else {
                        this.activeBlackScreen = false;
                        this.oncomplete.emit({ id: this.imageResult, documentInstance });
                    }
                }).catch(error => this.onerror.emit(new ResponseError(ErrorCode.FAIL_UPLOAD_IMAGE)));
            }, 500);
        });
    }
    getOcr(documentInstance) {
        const token = btoa(`${this.credentials.passiveUsername}:${this.credentials.passivePassword}`);
        this.service.getOcr(this.credentials.assureidEndpoint, documentInstance, token).then((response) => {
            this.idDataResult = Utils.parseIdData(response);
            if (this.idPhoto)
                this.getFaceImage(documentInstance, this.idDataResult);
            else {
                this.activeBlackScreen = false;
                this.oncomplete.emit({ id: this.imageResult, idData: this.idDataResult, documentInstance: documentInstance });
            }
        }).catch(error => this.onerror.emit(new ResponseError(ErrorCode.FAIL_GET_OCR)));
    }
    getFaceImage(documentInstance, idData) {
        const token = btoa(`${this.credentials.passiveUsername}:${this.credentials.passivePassword}`);
        if (idData && idData.ocr && idData.ocr.photo) {
            this.service.getFaceImage(idData.ocr.photo, token).then((response) => {
                this.activeBlackScreen = false;
                if (response)
                    this.oncomplete.emit({ id: this.imageResult, idData: this.idDataResult, idPhoto: response, documentInstance });
                else
                    this.onerror.emit(new ResponseError(ErrorCode.FACE_IMAGE_NOT_FOUND));
            }).catch(error => this.onerror.emit(new ResponseError(ErrorCode.FAIL_GET_FACE_IMAGE)));
        }
        else {
            this.activeBlackScreen = false;
            this.onerror.emit(new ResponseError(ErrorCode.FACE_IMAGE_URL_NOT_FOUND));
        }
    }
    ngOnDestroy() {
        this.showAutomaticCapture = false;
        this.showManualCapture = false;
        AcuantCameraUI.end();
        AcuantJavascriptWebSdk.endWorkers();
        Utils.removeScripts(DEPENDENCIES_TO_REMOVE);
        Utils.removeCustomizationStyle();
    }
};
NgFadAcuantComponent.ctorParameters = () => [
    { type: AcuantService }
];
__decorate([
    Input()
], NgFadAcuantComponent.prototype, "configuration", void 0);
__decorate([
    Input()
], NgFadAcuantComponent.prototype, "credentials", void 0);
__decorate([
    Input()
], NgFadAcuantComponent.prototype, "side", void 0);
__decorate([
    Input()
], NgFadAcuantComponent.prototype, "idData", void 0);
__decorate([
    Input()
], NgFadAcuantComponent.prototype, "idPhoto", void 0);
__decorate([
    Input()
], NgFadAcuantComponent.prototype, "imageQuality", void 0);
__decorate([
    Input()
], NgFadAcuantComponent.prototype, "documentInstance", void 0);
__decorate([
    Output()
], NgFadAcuantComponent.prototype, "oncomplete", void 0);
__decorate([
    Output()
], NgFadAcuantComponent.prototype, "onerror", void 0);
NgFadAcuantComponent = __decorate([
    Component({
        selector: 'ng-fad-acuant',
        template: "\n<div *ngIf=\"showAutomaticCapture\" id=\"container-acuant-camera\">\n  <div id=\"acuant-camera\"></div>\n</div>\n\n<div *ngIf=\"showManualCapture\" class=\"container-manual-capture\">\n  <div></div>\n  <div class=\"content-manual-capture\">\n    <img src=\"{{ configuration.pathDependencies.imageDirectory }}{{side == 1 ? 'id-back.svg': 'id-front.svg'}} \"/>\n    <span class=\"fad-subtitle\"> {{ configuration.customization.moduleCustomization.legends.manualCapture.instruction }} </span>\n  </div>\n  <button class=\"fad-primary\" (click)=\"startManualCapture()\"> {{ configuration.customization.moduleCustomization.legends.manualCapture.buttonNext }} </button>\n</div>\n\n<!-- black screen -->\n<div *ngIf=\"activeBlackScreen\" class=\"back-screen fad-content\">\n  <loader></loader>\n  <span> {{ configuration.customization.moduleCustomization.legends.initializing }} </span>\n</div>\n\n",
        animations: [FADE_IN_OUT_ANIMATION],
        styles: [".fad-title{font-family:var(--fad-common-title-font-family);font-size:var(--fad-common-title-font-size);font-weight:600}.fad-subtitle{font-family:var(--fad-common-subtitle-font-family);font-size:var(--fad-common-subtitle-font-size);font-weight:200}.fad-subtitle-bold{font-family:var(--fad-common-subtitle-font-family);font-size:var(--fad-common-subtitle-font-size);font-weight:600}.fad-content{font-family:var(--fad-common-content-font-family);font-size:var(--fad-common-content-font-size);font-weight:200}.fad-content-bold{font-family:var(--fad-common-content-font-family);font-size:var(--fad-common-content-font-size);font-weight:600}.fad-informative{font-family:var(--fad-common-informative-font-family);font-size:var(--fad-common-informative-font-size);font-weight:200}.fad-informative-bold{font-family:var(--fad-common-informative-font-family);font-size:var(--fad-common-informative-font-size);font-weight:600}.fad-button{font-family:var(---fad-common-button-font-family);font-size:var(--fad-common-button-font-size);font-family:var(--fad-common-button-font-family);font-size:var(--fad-common-button-font-size)}button{min-width:var(--fad-common-button-common-width);min-height:var(--fad-common-button-common-height);border-radius:var(--fad-common-button-common-border-radius);padding:var(--fad-common-button-common-padding);margin:var(--fad-common-button-common-margin);outline:var(--fad-common-button-common-outline);font-family:var(--fad-common-button-font-family);font-size:var(--fad-common-button-font-size);font-weight:300}button.fad-primary{background-color:var(--fad-common-primary-button-background-color);color:var(--fad-common-primary-button-label-color);border:var(--fad-common-primary-button-border)}button.fad-secondary{background-color:var(--fad-common-secondary-button-background-color);color:var(--fad-common-secondary-button-label-color);border:var(--fad-common-secondary-button-border)}button:disabled{background-color:var(--fad-common-primary-button-background-color-disabled);color:var(--fad-common-primary-button-label-color-disabled);border:none}.fad-button-bold{font-family:var(---fad-common-button-font-family);font-size:var(--fad-common-button-font-size);font-weight:600}.fad-link{font-family:var(--fad-common-subtitle-font-family);font-size:var(--fad-common-subtitle-font-size);color:#007aff;font-weight:200}.fad-link-bold{font-family:var(--fad-common-subtitle-font-family);font-size:var(--fad-common-subtitle-font-size);color:#007aff;font-weight:600}.fad-link-primary{font-family:var(--fad-common-subtitle-font-family);font-size:var(--fad-common-subtitle-font-size);color:var(--fad-common-primary-color);font-weight:200}.fad-link-primary-bold{font-family:var(--fad-common-subtitle-font-family);font-size:var(--fad-common-subtitle-font-size);color:var(--fad-common-primary-color);font-weight:600}.fad-button-link{font-family:var(--fad-common-subtitle-font-family);font-size:var(--fad-common-subtitle-font-size);color:#007aff;font-weight:200;border:1px solid #dadbe0;border-radius:7px;padding:5px;min-height:36px;width:100%;display:flex;align-items:center;justify-content:center}.fad-button-link-bold{font-family:var(--fad-common-subtitle-font-family);font-size:var(--fad-common-subtitle-font-size);color:#007aff;font-weight:600;border:1px solid #dadbe0;border-radius:7px;padding:5px;min-height:36px;width:100%;display:flex;align-items:center;justify-content:center}.fad-container-common-center{display:flex;flex-direction:column;align-items:center;justify-content:center;height:100%;width:100%;box-sizing:border-box;padding:3% 5%;text-align:center}.fad-container-common-center>img:last-of-type{margin-top:20px}.fad-container-common-center>img:first-child{margin-top:0}.fad-container-common-center>span{margin-top:10px}.fad-container-common-center>span:first-of-type{margin-top:15px}.fad-container-common-center>span:first-child{margin-top:0}.fad-container-common-space-between{display:flex;flex-direction:column;align-items:center;justify-content:space-between;height:100%;width:100%;box-sizing:border-box;padding:3% 5%;text-align:center}.fad-container-common-space-between .fad-container-title{display:flex;flex-direction:column;width:100%}.fad-container-common-space-between .fad-container-title>img:last-of-type{margin-top:20px}.fad-container-common-space-between .fad-container-title>img:first-child{margin-top:0}.fad-container-common-space-between .fad-container-title>span{margin-top:10px}.fad-container-common-space-between .fad-container-title>span:first-of-type{margin-top:15px}.fad-container-common-space-between .fad-container-title>span:first-child{margin-top:0}.fad-container-common-space-between .fad-container-title>div:last-child{margin-top:25px}#container-acuant-camera{width:100%;height:100%;display:flex;align-items:center;justify-content:center;background-color:#000}.back-screen{background-color:#000;position:fixed;width:100%;height:100%;top:0;left:0;display:flex;justify-content:center;align-items:center;flex-direction:column;color:#fff;z-index:2}.container-manual-capture{padding:3% 5%;width:100%;height:100%;display:flex;align-items:center;justify-content:space-between;box-sizing:border-box;flex-direction:column}.container-manual-capture .content-manual-capture{display:flex;flex-direction:column}.container-manual-capture .content-manual-capture span{margin:30px 0 20px}"]
    })
], NgFadAcuantComponent);

let LoaderComponent = class LoaderComponent {
    constructor() { }
    ngOnInit() {
    }
};
LoaderComponent = __decorate([
    Component({
        selector: 'loader',
        template: "<div class=\"spinner\">\n  <div class=\"double-bounce1\"></div>\n  <div class=\"double-bounce2\"></div>\n</div>\n",
        styles: [".spinner{width:40px;height:40px;position:relative;margin:10px auto}.double-bounce1,.double-bounce2{width:100%;height:100%;border-radius:50%;background-color:#fff;opacity:.6;position:absolute;top:0;left:0;-webkit-animation:2s ease-in-out infinite sk-bounce;animation:2s ease-in-out infinite sk-bounce}.double-bounce2{-webkit-animation-delay:-1s;animation-delay:-1s}@-webkit-keyframes sk-bounce{0%,100%{-webkit-transform:scale(0)}50%{-webkit-transform:scale(1)}}@keyframes sk-bounce{0%,100%{transform:scale(0);-webkit-transform:scale(0)}50%{transform:scale(1);-webkit-transform:scale(1)}}"]
    })
], LoaderComponent);

let NgFadAcuantModule = class NgFadAcuantModule {
};
NgFadAcuantModule = __decorate([
    NgModule({
        declarations: [NgFadAcuantComponent, LoaderComponent],
        imports: [CommonModule],
        exports: [NgFadAcuantComponent]
    })
], NgFadAcuantModule);

/*
 * Public API Surface of ng-fad-acuant
 */

/**
 * Generated bundle index. Do not edit.
 */

export { NgFadAcuantComponent, NgFadAcuantModule, FADE_IN_OUT_ANIMATION as ɵa, AcuantService as ɵb, LoaderComponent as ɵc };
//# sourceMappingURL=ng-fad-acuant.js.map
